@@ -5,6 +5,7 @@ from .line_nums import LineNumsPreproc, NumberedBlocksProcessor
 from .milestones import RE_MIL, MilestoneProcessor
 from .gaps_spaces import RE_SPACE, SpaceProcessor, RE_LINE_GAP, LineGapProcessor, RE_CHARACTER_GAP, CharacterGapProcessor
 from .to_xml import TEIPostprocesor
+from .misc import HetaProcessor, RE_HETA
 
 
 class LeidenPlus(Extension):
@@ -33,6 +34,7 @@ class LeidenPlus(Extension):
         md.inlinePatterns.register(SpaceProcessor(RE_SPACE, md), 'spaces', 119)
         md.inlinePatterns.register(LineGapProcessor(RE_LINE_GAP, md), 'line_gaps', 118)
         md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_GAP, md), 'character_gaps', 117)
+        md.inlinePatterns.register(HetaProcessor(RE_HETA, md), 'heta', 49) # After UnderscoreProcessor
         md.treeprocessors.register(DivisionMarkTreeproc(md), 'divison_treeproc', 120)
         md.postprocessors.register(TEIPostprocesor(md), 'to_xml', 0)
 
@@ -48,6 +50,3 @@ class LeidenEscape(Extension):
 # Some content
 # =>
 # ```
-
-# class LeidenEscape(Extension):
-#     pass
